__author__ = 'Casey Dunham'
__version__ = "0.1.1"


import urllib
import urllib2
import json


PWNED_API_URL = "https://haveibeenpwned.com/api/breachedaccount/%s"


class InvalidEmail(Exception):
    pass


def check(email):
    req = urllib2.Request(PWNED_API_URL % urllib.quote(email))
    try:
        resp = urllib2.urlopen(req)
        return json.loads(resp.read())
    except urllib2.HTTPError, e:
        if e.code == 400:
            raise InvalidEmail("Email address does not appear to be a valid email")
        return []




import pwnedcheck

from distutils.core import setup

setup(
    name="PwnedCheck",
    packages=["pwnedcheck"],
    package_dir={"pwnedcheck": "pwnedcheck"},
    version=pwnedcheck.__version__,
    description="Python package to interact with http://haveibeenpwned.com",
    long_description=open("README.rst").read() + "\n\n" + open("CHANGES.rst").read(),
    author="Casey Dunham",
    author_email="casey.dunham@gmail.com",
    url="https://github.com/caseydunham/PwnedCheck",
    license=open("LICENSE.rst").read(),
    classifiers=(
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Financial and Insurance Industry",
        "Intended Audience :: Healthcare Industry",
        "Intended Audience :: Information Technology",
        "Intended Audience :: System Administrators",
        "Natural Language :: English",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Security",
    )
)